@@ -43,7 +43,7 @@ or ~/.ssh/config (when run as a regular user).
         },
         'ordered' => '1',
         'type' => 'hash',
-        'description' => "The declarations make in 'parameters' are applied only to the hosts that match one of the patterns given in pattern elements. A single '*' as a pattern can be used to provide global defaults for all hosts. The host is the hostname argument given on the command line (i.e. the name is not converted to a canonicalized host name before matching). Since the first obtained value for each parameter is used, more host-specific declarations should be given near the beginning of the hash (which takes order into account), and general defaults at the end.",
+        'description' => 'The declarations make in \'parameters\' are applied only to the hosts that match one of the patterns given in pattern elements. A single \'*\' as a pattern can be used to provide global defaults for all hosts. The host is the hostname argument given on the command line (i.e. the name is not converted to a canonicalized host name before matching). Since the first obtained value for each parameter is used, more host-specific declarations should be given near the beginning of the hash (which takes order into account), and general defaults at the end.',
         'index_type' => 'string'
       }
     ],
